==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/UOMCONVERSIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour UOMCONVERSIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="UOMCONVERSIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMUOM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOUOM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UOMCONVERSIONID_Type", propOrder = {
    "fromuom",
    "touom"
})
public class UOMCONVERSIONID_Type {

    @XmlElement(name = "FROMUOM", required = true)
    protected UOMID_Type fromuom;
    @XmlElement(name = "TOUOM", required = true)
    protected UOMID_Type touom;

    /**
     * Obtient la valeur de la propriété fromuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getFROMUOM() {
        return fromuom;
    }

    /**
     * Définit la valeur de la propriété fromuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setFROMUOM(UOMID_Type value) {
        this.fromuom = value;
    }

    /**
     * Obtient la valeur de la propriété touom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getTOUOM() {
        return touom;
    }

    /**
     * Définit la valeur de la propriété touom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setTOUOM(UOMID_Type value) {
        this.touom = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/UOMCONVERSIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for UOMCONVERSIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="UOMCONVERSIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMUOM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOUOM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UOMCONVERSIONID_Type", propOrder = {
    "fromuom",
    "touom"
})
public class UOMCONVERSIONID_Type {

    @XmlElement(name = "FROMUOM", required = true)
    protected UOMID_Type fromuom;
    @XmlElement(name = "TOUOM", required = true)
    protected UOMID_Type touom;

    /**
     * Gets the value of the fromuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getFROMUOM() {
        return fromuom;
    }

    /**
     * Sets the value of the fromuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setFROMUOM(UOMID_Type value) {
        this.fromuom = value;
    }

    /**
     * Gets the value of the touom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getTOUOM() {
        return touom;
    }

    /**
     * Sets the value of the touom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setTOUOM(UOMID_Type value) {
        this.touom = value;
    }

}
